JSON Color Names
================

_A curated collection of color names to RGB hex code mappings_

![https://travis-ci.org/bpeterso2000/color-names](https://travis-ci.org/bpeterso2000/color-names.svg?branch=master)


Language Agnostic
-----------------
This project is language agnostic; all color mappings are stored in
JSON format.

Styles
------
*All JSON style files are located in the color-names directory.*

| Color Style                              | Description                              | Created By                               |
| ---------------------------------------- | ---------------------------------------- | ---------------------------------------- |
| [Solarized](http://ethanschoonover.com/solarized) | Precision colors for machines and people. | [Ethan Schoonover](http://ethanschoonover.com/) |
| [Monokai](https://github.com/tomasr/molokai) | A port of the theme for TextMate.        | [Wimer Hazenberg](https://www.monokai.nl/) |
| [Tomorrow Night](https://github.com/chriskempson/tomorrow-theme) | A bright theme with pastel colors.       | [Chris Kempson](https://github.com/chriskempson) |
| [HTML](https://www.webstandards.org/learn/reference/charts/color_names/) | Legal color names in HTML 4, XHTML 1.0, 1.1 |                                          |
| [CSS](https://draft)                     | Legal color names in CSS 4.              |                                          |
| [Crayons](http://www.crayola.com/explore-colors) | Crayola (R) Crayon Colors.               | [Crayola](http://www.crayola.com/)       |
| [Chalk](https://designpieces.com/2014/02/chalkboard-look-and-feel/) | Hipster chalkboard look and feel.        | [Nick Georgiou](https://designpieces.com/author/nick/) |
| [Better Colors](http://clrs.cc/)         | A nicer color palette for the web.       | [MRMRS](http://mrmrs.cc/)                |


Tests
-----
Python is included for testing & continuous integration purposes only.

License
-------
This work is free of known copyright restrictions.

